@@ -11,6 +11,7 @@ extern int  primality_pretest(mpz_t n);
 
 extern void _GMP_next_prime(mpz_t n);
 extern void _GMP_prev_prime(mpz_t n);
+extern void surround_primes(mpz_t n, UV* prev, UV* next, UV skip_width);
 
 extern void _GMP_pn_primorial(mpz_t prim, UV n);
 extern void _GMP_primorial(mpz_t prim, UV n);
@@ -26,7 +27,10 @@ extern void exp_mangoldt(mpz_t res, mpz_t n);
 
 extern uint32_t* partial_sieve(mpz_t start, UV length, UV maxprime);
 extern char* pidigits(UV n);
+extern char* bernreal(mpz_t zn, unsigned long prec);
 extern char* harmreal(mpz_t zn, unsigned long prec);
+extern char* zetareal(mpf_t r, unsigned long prec);
+extern char* riemannrreal(mpf_t r, unsigned long prec);
 
 extern UV* sieve_primes(mpz_t low, mpz_t high, UV k, UV *rn);
 extern UV* sieve_twin_primes(mpz_t low, mpz_t high, UV twin, UV *rn);
