@@ -87,6 +87,12 @@ extern int* poly_class_nums(void);
  */
 extern UV poly_class_poly_num(int i, int *D, mpz_t**T, int* type);
 
+extern void mpf_log(mpf_t logx, mpf_t x);
+extern void mpf_exp(mpf_t expx, mpf_t x);
+extern void mpf_pow(mpf_t powx, mpf_t b, mpf_t x);
+
+
+
 #if defined(FUNC_isqrt) || defined(FUNC_is_perfect_square)
 static UV isqrt(UV n) {
   UV root;
